@@ -2,7 +2,7 @@
 Handles paradigm generation.
 """
 
-import string
+from pathlib import Path
 from .manager import *
 from . import settings
 
@@ -19,7 +19,7 @@ def default_paradigm_manager() -> ParadigmManager:
     """
 
     # Directory with paradigm layouts to load
-    layout_dir = settings.get_layouts_dir()
+    layout_dir = Path(settings.get_layouts_dir())
 
     generator = strict_generator()
 
@@ -33,12 +33,13 @@ def default_paradigm_manager() -> ParadigmManager:
         return ParadigmManager(layout_dir, generator)
 
 def strict_generator():
+    """
+    FST file to do translations
+    """
     path = settings.get_fst_filepath()
-    print(path, "pathhhh")
     try:
         return TransducerFile(path)
     except Exception as error:
-        print("\\" + str(error).split(":")[0] + "\\")
         if (str(error).split(":")[0] == 'Transducer not found'):
             raise Exception(str(error).split(":")[0] + f' in \"{path}\"')
         else:
